@@ -11,6 +11,7 @@ package Kernel::Modules::AdminCustomerUserCustomer;
 
 use strict;
 use warnings;
+use utf8;
 
 our $ObjectManagerDisabled = 1;
 
@@ -509,7 +510,9 @@ sub _Overview {
 
     $LayoutObject->Block(
         Name => 'Overview',
-        Data => {},
+        Data => {
+            OverviewLink => $Self->{Action} . ';Search=' . $Param{Search},
+        },
     );
 
     $LayoutObject->Block( Name => 'ActionList' );
