@@ -1,20 +1,18 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
 # did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
-## nofilter(TidyAll::Plugin::OTRS::Perl::ParamObject)
+## nofilter(TidyAll::Plugin::Znuny::Perl::ParamObject)
 
 package Kernel::System::Calendar::Plugin;
 
 use strict;
 use warnings;
 
-use Kernel::System::VariableCheck qw(:all);
-
 our @ObjectDependencies = (
     'Kernel::Config',
     'Kernel::System::JSON',
@@ -128,7 +126,7 @@ run given plugin function with all existing params.
         PluginKey      => 'TicketLink',
         PluginFunction => 'Search',
         PluginData     => {
-            UserID    => 1
+            UserID    => 1,
             Search    => 'SearchTerm',      # (required) Search string
                                             # or
             ObjectID  => $TicketID          # (required) Object ID
@@ -154,12 +152,13 @@ sub PluginFunction {
     }
 
     my $PluginObject   = $Self->{Plugins}->{ $Param{PluginKey} }->{Object};
+    my $PluginModule   = $Self->{Plugins}->{ $Param{PluginKey} }->{Module};
     my $PluginFunction = $Param{PluginFunction};
 
-    if ( $MainObject->Require( $PluginObject, Silent => 1 ) ) {
+    if ( !$MainObject->Require( $PluginModule, Silent => 1 ) ) {
         $LogObject->Log(
             Priority => 'error',
-            Message  => "Sorry, can't load $PluginObject!",
+            Message  => "Sorry, can't load $PluginModule!",
         );
         return;
     }
@@ -168,7 +167,7 @@ sub PluginFunction {
     if ( !$Exists ) {
         $LogObject->Log(
             Priority => 'notice',
-            Message  => "Sorry, can't load function $PluginFunction in $PluginObject!",
+            Message  => "Sorry, can't load function $PluginFunction in $PluginModule!",
         );
         return;
     }
@@ -443,7 +442,7 @@ Returns:
             ChangeTime    => '...',
             ChangeBy      => '...',
         },
-        ...
+        # ...
     );
 
 =cut
@@ -516,7 +515,7 @@ Returns:
             'ChangeTime'    => '...',
             'ChangeBy'      => '...',
         },
-        ...
+        # ...
     );
 
 =cut
