@@ -48,14 +48,21 @@ sub Configure {
         ValueRegex  => qr/.+/,
     );
     $Self->AddOption(
-        Name => 'generate-po',
+        Name        => 'generate-po',
         Description =>
             "Generate PO (translation content) files. This is only needed if a module is not yet available in Weblate to force initial creation of the gettext files.",
         Required => 0,
         HasValue => 0,
     );
     $Self->AddOption(
-        Name => 'keep-old',
+        Name        => 'regenerate',
+        Description => "All translation files are regenerated so that all unused translations are removed.",
+        Required    => 0,
+        HasValue    => 0,
+    );
+
+    $Self->AddOption(
+        Name        => 'keep-old',
         Description =>
             "Keep old language files (e.g. Kernel/Language/de_GeneralCatalog.pm). This is only needed if you want to diff these files.",
         Required => 0,
@@ -337,7 +344,7 @@ sub HandleLanguage {
         },
     );
     if ( $TranslitLanguagesMap{$Language} ) {
-        $TranslitObject = new Lingua::Translit( $TranslitLanguagesMap{$Language}->{TranslitTable} );    ## no critic
+        $TranslitObject             = new Lingua::Translit( $TranslitLanguagesMap{$Language}->{TranslitTable} );    ## no critic
         $TranslitLanguageCoreObject = Kernel::Language->new(
             UserLanguage    => $TranslitLanguagesMap{$Language}->{SourceLanguage},
             TranslationFile => 1,
@@ -474,16 +481,28 @@ sub WritePOFile {
 
     my $POEntries = Locale::PO->load_file_asarray( $Param{TargetPOFile} );
     my %POLookup;
+    my @POEntries;
 
-    for my $Entry ( @{$POEntries} ) {
-        my $Source = $Entry->dequote( $Entry->msgid() );
-        $Source =~ s/\\{2}/\\/g;
-        $EncodeObject->EncodeInput( \$Source );
-        $POLookup{$Source} = $Entry;
+    if ( $Self->GetOption('regenerate') ) {
+
+        # Add the first entry again with comments and po header lines
+        push @POEntries, $POEntries->[0] if defined $POEntries->[0];
+    }
+    else {
+        for my $Entry ( @{$POEntries} ) {
+            my $Source = $Entry->dequote( $Entry->msgid() );
+            $Source =~ s/\\{2}/\\/g;
+            $EncodeObject->EncodeInput( \$Source );
+            $POLookup{$Source} = $Entry;
+        }
+
+        # Get the current entries
+        @POEntries = @{$POEntries};
     }
 
     for my $String ( @{ $Param{TranslationStrings} } ) {
 
+        # Encode the strings
         my $Source = $String->{Source};
         $Source =~ s/\\/\\\\/g;
         $EncodeObject->EncodeOutput( \$Source );
@@ -491,27 +510,36 @@ sub WritePOFile {
         $Translation =~ s/\\/\\\\/g;
         $EncodeObject->EncodeOutput( \$Translation );
 
-        # Is there an entry in the PO already?
-        if ( exists $POLookup{ $String->{Source} } ) {
+        if ( $Self->GetOption('regenerate') ) {
 
-            # Yes, update it
-            $POLookup{ $String->{Source} }->msgstr($Translation);
-            $POLookup{ $String->{Source} }->automatic( $String->{Location} );
-        }
-        else {
-
-            # No PO entry yet, create one.
-            push @{$POEntries}, Locale::PO->new(
+            # Create new one.
+            push @POEntries, Locale::PO->new(
                 -msgid     => $Source,
                 -msgstr    => $Translation,
                 -automatic => $String->{Location},
             );
         }
+        else {
+            # Is there an entry in the PO already and you want to keep them?
+            if ( exists $POLookup{ $String->{Source} } ) {
+
+                # Yes, update it.
+                $POLookup{ $String->{Source} }->msgstr($Translation);
+                $POLookup{ $String->{Source} }->automatic( $String->{Location} );
+            }
+            else {
+
+                # No PO entry yet, create one.
+                push @POEntries, Locale::PO->new(
+                    -msgid     => $Source,
+                    -msgstr    => $Translation,
+                    -automatic => $String->{Location},
+                );
+            }
+        }
     }
 
-    # Theoretically we could now also check for removed strings, but since the translations
-    #   are handled by Weblate, this will not be needed as Weblate will handle that for us.
-    Locale::PO->save_file_fromarray( $Param{TargetPOFile}, $POEntries )
+    Locale::PO->save_file_fromarray( $Param{TargetPOFile}, \@POEntries )
         || die "Could not save file $Param{TargetPOFile}: $!";
 
     return 1;
@@ -534,7 +562,7 @@ sub WritePOTFile {
     );
 
     push @POTEntries, Locale::PO->new(
-        -msgid => '',
+        -msgid  => '',
         -msgstr =>
             "Project-Id-Version: $Package\n" .
             "POT-Creation-Date: $CreationDate\n" .
@@ -564,7 +592,7 @@ sub WritePOTFile {
     if ( -e $Param{TargetPOTFile} ) {
         my %PreviousPOTEntries = $Self->LoadPOFile( TargetPOFile => $Param{TargetPOTFile} );
         my @PreviousPOTEntries = sort grep { length $_ } keys %PreviousPOTEntries;
-        my @NewPOTEntries      = sort map { $_->{Source} } @{ $Param{TranslationStrings} };
+        my @NewPOTEntries      = sort map  { $_->{Source} } @{ $Param{TranslationStrings} };
         my $DataIsDifferent    = DataIsDifferent(
             Data1 => \@PreviousPOTEntries,
             Data2 => \@NewPOTEntries
