@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -8,10 +8,11 @@
 # --
 
 package Kernel::System::Log;
-## nofilter(TidyAll::Plugin::OTRS::Perl::PODSpelling)
-## nofilter(TidyAll::Plugin::OTRS::Perl::Time)
-## nofilter(TidyAll::Plugin::OTRS::Perl::Dumper)
-## nofilter(TidyAll::Plugin::OTRS::Perl::Require)
+
+## nofilter(TidyAll::Plugin::Znuny::Perl::Time)
+## nofilter(TidyAll::Plugin::Znuny::Perl::Dumper)
+## nofilter(TidyAll::Plugin::Znuny::Perl::Require)
+## nofilter(TidyAll::Plugin::Znuny::CodeStyle::STDERRCheck)
 
 use strict;
 use warnings;
@@ -20,6 +21,7 @@ use Carp ();
 
 our @ObjectDependencies = (
     'Kernel::Config',
+    'Kernel::System::DateTime',
     'Kernel::System::Encode',
 );
 
@@ -95,7 +97,7 @@ sub new {
     return $Self if !eval "require IPC::SysV";    ## no critic
 
     # Setup IPC for shared access to the last log entries.
-    $Self->{IPCKey} = '444423' . $SystemID;       # This name is used to identify the shared memory segment.
+    $Self->{IPCKey}  = '444423' . $SystemID;      # This name is used to identify the shared memory segment.
     $Self->{IPCSize} = $ConfigObject->Get('LogSystemCacheSize') || 32 * 1024;
 
     # Create/access shared memory segment.
@@ -164,7 +166,7 @@ See for more info L<http://en.wikipedia.org/wiki/Syslog#Severity_levels>
 sub Log {
     my ( $Self, %Param ) = @_;
 
-    my $Priority    = lc $Param{Priority}  || 'debug';
+    my $Priority    = lc( $Param{Priority} // 'debug' );
     my $PriorityNum = $LogLevel{$Priority} || $LogLevel{debug};
 
     return 1 if $PriorityNum < $Self->{MinimumLevelNum};
@@ -257,7 +259,7 @@ sub Log {
     if ( lc $Priority ne 'debug' && $Self->{IPC} ) {
         $Priority = lc $Priority;
 
-        my $Data   = $LogTime . ";;$Priority;;$Self->{LogPrefix};;$Message\n";    ## no critic
+        my $Data   = $LogTime . ";;$Priority;;$Self->{LogPrefix};;$Subroutine2;;$Line1;;$Message\n";    ## no critic
         my $String = $Self->GetLog();
 
         # Fix for issue #286 (GitHub) / #328 (internal): Encode output.
@@ -272,13 +274,85 @@ sub Log {
     return 1;
 }
 
+=head2 Error()
+
+Convenience function to log an error message.
+
+    $LogObject->Error("Something went wrong!");
+
+=cut
+
+sub Error {
+    my ( $Self, $Message ) = @_;
+
+    return $Self->Log(
+        Priority => 'error',
+        Message  => $Message,
+        Caller   => 1,
+    );
+}
+
+=head2 Notice()
+
+Convenience function to log a notice.
+
+    $LogObject->Notice("Heads up! SNAFU has happened!");
+
+=cut
+
+sub Notice {
+    my ( $Self, $Message ) = @_;
+
+    return $Self->Log(
+        Priority => 'notice',
+        Message  => $Message,
+        Caller   => 1,
+    );
+}
+
+=head2 Info()
+
+Convenience function to log an informational message.
+
+    $LogObject->Info("Oh by the way, this thing worked.");
+
+=cut
+
+sub Info {
+    my ( $Self, $Message ) = @_;
+
+    return $Self->Log(
+        Priority => 'info',
+        Message  => $Message,
+        Caller   => 1,
+    );
+}
+
+=head2 Debug()
+
+Convenience function to log a message at debug level.
+
+    $LogObject->Debug("You won't want to see this unless you're a developer.");
+
+=cut
+
+sub Debug {
+    my ( $Self, $Message ) = @_;
+
+    return $Self->Log(
+        Priority => 'debug',
+        Message  => $Message,
+        Caller   => 1,
+    );
+}
+
 =head2 GetLogEntry()
 
 to get the last log info back
 
     my $Message = $LogObject->GetLogEntry(
-        Type => 'error', # error|info|notice
-        What => 'Message', # Message|Traceback
+        Type => 'error',    # error|info|notice
+        What => 'Message',  # Message|Traceback
     );
 
 =cut
