@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -19,14 +19,16 @@ use parent qw(Kernel::System::ProcessManagement::TransitionAction::Base);
 
 our @ObjectDependencies = (
     'Kernel::Config',
+    'Kernel::System::DateTime',
     'Kernel::System::DynamicField',
     'Kernel::System::DynamicField::Backend',
+    'Kernel::System::HTMLUtils',
     'Kernel::System::LinkObject',
     'Kernel::System::Log',
     'Kernel::System::State',
+    'Kernel::System::StdAttachment',
     'Kernel::System::Ticket',
     'Kernel::System::Ticket::Article',
-    'Kernel::System::DateTime',
     'Kernel::System::User',
 );
 
@@ -60,15 +62,19 @@ sub new {
 
 =head2 Run()
 
-    Run Data
+Runs TransitionAction TicketCreate.
 
     my $TicketCreateResult = $TicketCreateActionObject->Run(
         UserID                   => 123,
+
+        # Ticket contains the result of TicketGet including dynamic fields
         Ticket                   => \%Ticket,   # required
         ProcessEntityID          => 'P123',
         ActivityEntityID         => 'A123',
         TransitionEntityID       => 'T123',
         TransitionActionEntityID => 'TA123',
+
+        # Config is the hash stored in a Process::TransitionAction's config key
         Config                   => {
             # ticket required:
             Title         => 'Some Ticket Title',
@@ -98,7 +104,12 @@ sub new {
             %DataPayload,                                               # some parameters depending of each communication channel
 
             # article optional:
-            TimeUnit => 123
+            TimeUnit => 123,
+
+            # Attachment optional:
+            Attachments      => 'StdAttachmentName1,StdAttachmentName2', # optional, comma separated StandardAttachment Names
+            AttachmentIDs    => '1,2,3',                                 # optional, comma separated StandardAttachment ID
+            AttachmentsReuse => 1                                        # optional, 1|0 - Reuse of attachments stored in the dynamic field configured in Process::DynamicFieldProcessManagementAttachment.
 
             # other:
             DynamicField_NameX => $Value,
@@ -106,19 +117,22 @@ sub new {
             UserID => 123,                                              # optional, to override the UserID from the logged user
         }
     );
-    Ticket contains the result of TicketGet including DynamicFields
-    Config is the Config Hash stored in a Process::TransitionAction's  Config key
-    Returns:
 
-    $TicketCreateResult = 1; # 0
+Returns:
 
-    );
+    my $Success = 1; # 0
 
 =cut
 
 sub Run {
     my ( $Self, %Param ) = @_;
 
+    my $StdAttachmentObject       = $Kernel::OM->Get('Kernel::System::StdAttachment');
+    my $DynamicFieldObject        = $Kernel::OM->Get('Kernel::System::DynamicField');
+    my $DynamicFieldBackendObject = $Kernel::OM->Get('Kernel::System::DynamicField::Backend');
+    my $HTMLUtilsObject           = $Kernel::OM->Get('Kernel::System::HTMLUtils');
+    my $LogObject                 = $Kernel::OM->Get('Kernel::System::Log');
+
     # define a common message to output in case of any error
     my $CommonMessage = "Process: $Param{ProcessEntityID} Activity: $Param{ActivityEntityID}"
         . " Transition: $Param{TransitionEntityID}"
@@ -134,6 +148,34 @@ sub Run {
     # override UserID if specified as a parameter in the TA config
     $Param{UserID} = $Self->_OverrideUserID(%Param);
 
+    if (
+        defined $Param{Config}->{Body}
+        && $Param{Config}->{Body} =~ /OTRS_TICKET_DynamicField_/
+        )
+    {
+        MATCH:
+        for my $Match ( sort keys %{ $Param{Ticket} } ) {
+            if ( $Match =~ m/DynamicField_(.*)/ && $Param{Ticket}->{$Match} ) {
+
+                my $DynamicFieldConfig = $DynamicFieldObject->DynamicFieldGet(
+                    Name => $1,
+                );
+
+                # Check if there is HTML content.
+                my $IsHTMLContent = $DynamicFieldBackendObject->HasBehavior(
+                    DynamicFieldConfig => $DynamicFieldConfig,
+                    Behavior           => 'IsHTMLContent',
+                );
+
+                # Avoid double conversion to HTML for dynamic fields with HTML content.
+                next MATCH if $IsHTMLContent;
+                $Param{Ticket}->{$Match} = $HTMLUtilsObject->ToHTML(
+                    String => $Param{Ticket}->{$Match},
+                );
+            }
+        }
+    }
+
     # use ticket attributes if needed
     $Self->_ReplaceTicketAttributes(%Param);
     $Self->_ReplaceAdditionalAttributes(%Param);
@@ -190,7 +232,7 @@ sub Run {
         UserID => $Param{UserID},
     );
     if ( !$TicketID ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $LogObject->Log(
             Priority => 'error',
             Message  => $CommonMessage
                 . "Couldn't create New Ticket from Ticket: "
@@ -289,6 +331,53 @@ sub Run {
             ChannelName => $Param{Config}->{CommunicationChannel},
         );
 
+        # attachments
+        if ( $Param{Config}->{AttachmentsReuse} ) {
+            $Param{Config}->{Attachment} = $Self->_GetAttachments(%Param);
+        }
+
+        if ( $Param{Config}->{Attachments} || $Param{Config}->{AttachmentIDs} ) {
+            my @AttachmentIDs = split /\s*,\s*/, ( $Param{Config}->{AttachmentIDs} || '' );
+
+            my @AttachmentNames = split /\s*,\s*/, ( $Param{Config}->{Attachments} || '' );
+            ATTACHMENT:
+            for my $Name (@AttachmentNames) {
+                my $ID = $StdAttachmentObject->StdAttachmentLookup(
+                    StdAttachment => $Name,
+                );
+                next ATTACHMENT if !$ID;
+
+                push @AttachmentIDs, $ID;
+            }
+
+            ATTACHMENT:
+            for my $ID (@AttachmentIDs) {
+                my %Data = $StdAttachmentObject->StdAttachmentGet(
+                    ID => $ID,
+                );
+                next ATTACHMENT if !%Data;
+
+                if ( $Data{ValidID} != 1 ) {
+                    $LogObject->Log(
+                        Priority => 'error',
+                        Message  => $CommonMessage
+                            . 'Attachment (ID: '
+                            . $ID
+                            . ', Name: '
+                            . $Data{Name}
+                            . ') is invalid. Skip Attachment!',
+                    );
+                    next ATTACHMENT;
+                }
+
+                push @{ $Param{Config}->{Attachment} }, {
+                    Content     => $Data{Content},
+                    ContentType => $Data{ContentType},
+                    Filename    => $Data{Filename},
+                };
+            }
+        }
+
         # Create article for the new ticket.
         $ArticleID = $ArticleBackendObject->ArticleCreate(
             %{ $Param{Config} },
@@ -297,7 +386,7 @@ sub Run {
         );
 
         if ( !$ArticleID ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $LogObject->Log(
                 Priority => 'error',
                 Message  => $CommonMessage
                     . "Couldn't create Article on Ticket: $TicketID from Ticket: "
@@ -328,10 +417,6 @@ sub Run {
         }
     }
 
-    # get dynamic field objects
-    my $DynamicFieldObject        = $Kernel::OM->Get('Kernel::System::DynamicField');
-    my $DynamicFieldBackendObject = $Kernel::OM->Get('Kernel::System::DynamicField::Backend');
-
     # get the dynamic fields for ticket
     my $DynamicFieldList = $DynamicFieldObject->DynamicFieldListGet(
         Valid       => 1,
@@ -362,7 +447,7 @@ sub Run {
         );
 
         if ( !$Success ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $LogObject->Log(
                 Priority => 'error',
                 Message  => $CommonMessage
                     . "Couldn't set DynamicField Value on $DynamicFieldConfig->{ObjectType}:"
@@ -405,7 +490,7 @@ sub Run {
         }
 
         if ( !$SelectedType ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $LogObject->Log(
                 Priority => 'error',
                 Message  => $CommonMessage
                     . "LinkAs $Param{LinkAs} is invalid!"
@@ -431,7 +516,7 @@ sub Run {
         );
 
         if ( !$Success ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $LogObject->Log(
                 Priority => 'error',
                 Message  => $CommonMessage
                     . "Couldn't Link Tickets $SourceObjectID with $TargetObjectID as $Param{LinkAs}!",
