@@ -12,9 +12,9 @@ package Kernel::System::Ticket::Article::Backend::MIMEBase::ArticleStorageFS;
 use strict;
 use warnings;
 
-use File::Path qw();
-use MIME::Base64 qw();
-use Time::HiRes qw();
+use File::Path         qw();
+use MIME::Base64       qw();
+use Time::HiRes        qw();
 use Unicode::Normalize qw();
 
 use parent qw(Kernel::System::Ticket::Article::Backend::MIMEBase::Base);
@@ -24,8 +24,6 @@ use Kernel::System::VariableCheck qw(:all);
 our @ObjectDependencies = (
     'Kernel::Config',
     'Kernel::System::Cache',
-    'Kernel::System::DB',
-    'Kernel::System::DynamicFieldValue',
     'Kernel::System::Encode',
     'Kernel::System::Log',
     'Kernel::System::Main',
@@ -63,9 +61,9 @@ sub new {
 
         $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
-            Message  => "Can't write $ArticleDir! try: \$OTRS_HOME/bin/otrs.SetPermissions.pl!",
+            Message  => "Can't write $ArticleDir! try: \$OTRS_HOME/bin/znuny.SetPermissions.pl!",
         );
-        die "Can't write $ArticleDir! try: \$OTRS_HOME/bin/otrs.SetPermissions.pl!";
+        die "Can't write $ArticleDir! try: \$OTRS_HOME/bin/znuny.SetPermissions.pl!";
     }
 
     # Get activated cache backend configuration.
@@ -325,7 +323,8 @@ sub ArticleWriteAttachment {
     my $NewFileName = $Param{Filename};
     my %UsedFile;
     my %Index = $Self->ArticleAttachmentIndex(
-        ArticleID => $Param{ArticleID},
+        ArticleID     => $Param{ArticleID},
+        OnlyMyBackend => 1,
     );
 
     # Normalize filenames to find file names which are identical but in a different unicode form.
