@@ -482,7 +482,7 @@ Core.SystemConfiguration = (function (TargetNS) {
             URL,
             Value,
             function(Response) {
-                var LinkURL = 'Action=AdminSystemConfigurationDeployment;Subaction=Deployment';
+                var LinkURL = Core.Config.Get('Baselink') + 'Action=AdminSystemConfigurationDeployment;Subaction=Deployment';
 
                 TargetNS.CleanWidgetClasses($Widget);
                 TargetNS.SettingRender(Response, $Widget);
@@ -492,25 +492,28 @@ Core.SystemConfiguration = (function (TargetNS) {
                         LinkURL += ';' + Core.Config.Get('SessionName') + '=' + Core.Config.Get('SessionID');
                     }
 
-                    Core.UI.ShowNotification(
-                        Core.Language.Translate('You have undeployed settings, would you like to deploy them?'),
-                        'Notice',
-                        LinkURL,
+                    if (!$('#QuickDeployNotification').length) {
+                        Core.UI.ShowNotificationTemplate(
+                            {
+                                ID: 'QuickDeployNotification',
+                                Template: 'SysConfig/DirtyCheck',
+                                Type: 'Notice',
+                                Icon: 'fa-bell',
+                                Link: LinkURL,
+                            }
+                        );
+                    }
+
+                }
+                else if (Response.Data.DeploymentNeeded == 0) {
+
+                    Core.UI.HideNotification(
+                        undefined,
+                        undefined,
                         function() {
                             Core.UI.InitStickyElement();
                         },
-                        undefined,
-                        'fa-bell'
-                    );
-                    Core.UI.InitMessageBoxClose();
-                }
-                else if (Response.Data.DeploymentNeeded == 0) {
-                    Core.UI.HideNotification(
-                        Core.Language.Translate('You have undeployed settings, would you like to deploy them?'),
-                        'Notice',
-                        function() {
-                            Core.UI.InitStickyElement();
-                        }
+                        'QuickDeployNotification'
                     );
                 }
 
@@ -1082,7 +1085,7 @@ Core.SystemConfiguration = (function (TargetNS) {
             Core.Config.Get('Baselink'),
             Data,
             function(Response) {
-                var LinkURL = 'Action=AdminSystemConfigurationDeployment;Subaction=Deployment';
+                var LinkURL = Core.Config.Get('Baselink') + 'Action=AdminSystemConfigurationDeployment;Subaction=Deployment';
 
                 TargetNS.SettingRender(Response, $Widget);
                 TargetNS.CleanWidgetClasses($Widget);
@@ -1098,28 +1101,31 @@ Core.SystemConfiguration = (function (TargetNS) {
 
                         // hide the "deployment" notification
                         Core.UI.HideNotification(
-                            Core.Language.Translate('You have undeployed settings, would you like to deploy them?'),
-                            'Notice',
+                            undefined,
+                            undefined,
                             function() {
                                 Core.UI.InitStickyElement();
-                            }
+                            },
+                            'QuickDeployNotification'
                         );
                     }
                     else {
                         if (Core.Config.Get('SessionUseCookie') === '0') {
                             LinkURL += ';' + Core.Config.Get('SessionName') + '=' + Core.Config.Get('SessionID');
                         }
-                        Core.UI.ShowNotification(
-                            Core.Language.Translate('You have undeployed settings, would you like to deploy them?'),
-                            'Notice',
-                            LinkURL,
-                            function() {
-                                Core.UI.InitStickyElement();
-                            },
-                            undefined,
-                            'fa-bell'
-                        );
-                        Core.UI.InitMessageBoxClose();
+
+                        if (!$('#QuickDeployNotification').length) {
+                            Core.UI.ShowNotificationTemplate(
+                                {
+                                    ID: 'QuickDeployNotification',
+                                    Template: 'SysConfig/DirtyCheck',
+                                    Type: 'Notice',
+                                    Icon: 'fa-bell',
+                                    Link: LinkURL,
+                                }
+                            );
+                        }
+
                     }
                 }
                 Core.App.Publish('SystemConfiguration.SettingListUpdate');
